"use client"

import { useState, useEffect } from "react"
import Link from "next/link"
import { useTheme } from "next-themes"
import { Button } from "@/components/ui/button"
import { MoonIcon, SunIcon, Menu, X } from "lucide-react"
import { motion, AnimatePresence } from "framer-motion"
import LanguageSwitcher from "./LanguageSwitcher"

export default function Header() {
  const [mounted, setMounted] = useState(false)
  const { theme, setTheme } = useTheme()
  const [isMenuOpen, setIsMenuOpen] = useState(false)
  const [scrolled, setScrolled] = useState(false)

  useEffect(() => {
    setMounted(true)

    const handleScroll = () => {
      setScrolled(window.scrollY > 10)
    }

    window.addEventListener("scroll", handleScroll)
    return () => window.removeEventListener("scroll", handleScroll)
  }, [])

  const toggleMenu = () => {
    setIsMenuOpen(!isMenuOpen)
  }

  return (
    <header
      className={`sticky top-0 z-50 w-full transition-all duration-300 ${
        scrolled ? "glass-effect backdrop-blur-md" : "bg-transparent"
      }`}
    >
      <div className="container flex h-16 items-center justify-between">
        <Link href="/" className="flex items-center gap-2">
          <span className="text-xl font-bold golden-text golden-glow">Anamur AI</span>
        </Link>

        <nav className="hidden md:flex items-center gap-6">
          <Link href="#services" className="text-sm font-medium text-gray-300 hover:text-primary transition-colors">
            Hizmetler
          </Link>
          <Link href="#technology" className="text-sm font-medium text-gray-300 hover:text-primary transition-colors">
            Teknoloji
          </Link>
          <Link href="#sectors" className="text-sm font-medium text-gray-300 hover:text-primary transition-colors">
            Sektörler
          </Link>
          <Link href="#about" className="text-sm font-medium text-gray-300 hover:text-primary transition-colors">
            Hakkımızda
          </Link>
          <Link href="#contact" className="text-sm font-medium text-gray-300 hover:text-primary transition-colors">
            İletişim
          </Link>
        </nav>

        <div className="flex items-center gap-2">
          {mounted && (
            <Button
              variant="ghost"
              size="icon"
              onClick={() => setTheme(theme === "dark" ? "light" : "dark")}
              className="mr-2 text-gray-300 hover:text-primary hover:bg-background/20"
            >
              {theme === "dark" ? <SunIcon className="h-5 w-5" /> : <MoonIcon className="h-5 w-5" />}
              <span className="sr-only">Toggle theme</span>
            </Button>
          )}

          <div className="hidden md:block">
            <LanguageSwitcher currentLanguage="tr" onLanguageChange={() => {}} />
          </div>

          <Button
            variant="ghost"
            size="icon"
            className="md:hidden text-gray-300 hover:text-primary hover:bg-background/20"
            onClick={toggleMenu}
          >
            {isMenuOpen ? <X className="h-5 w-5" /> : <Menu className="h-5 w-5" />}
            <span className="sr-only">Toggle menu</span>
          </Button>
        </div>
      </div>

      <AnimatePresence>
        {isMenuOpen && (
          <motion.div
            initial={{ opacity: 0, height: 0 }}
            animate={{ opacity: 1, height: "auto" }}
            exit={{ opacity: 0, height: 0 }}
            className="md:hidden glass-effect"
          >
            <div className="container py-4 flex flex-col gap-4">
              <Link
                href="#services"
                className="text-sm font-medium p-2 hover:bg-white/5 rounded-md text-gray-300"
                onClick={() => setIsMenuOpen(false)}
              >
                Hizmetler
              </Link>
              <Link
                href="#technology"
                className="text-sm font-medium p-2 hover:bg-white/5 rounded-md text-gray-300"
                onClick={() => setIsMenuOpen(false)}
              >
                Teknoloji
              </Link>
              <Link
                href="#sectors"
                className="text-sm font-medium p-2 hover:bg-white/5 rounded-md text-gray-300"
                onClick={() => setIsMenuOpen(false)}
              >
                Sektörler
              </Link>
              <Link
                href="#about"
                className="text-sm font-medium p-2 hover:bg-white/5 rounded-md text-gray-300"
                onClick={() => setIsMenuOpen(false)}
              >
                Hakkımızda
              </Link>
              <Link
                href="#contact"
                className="text-sm font-medium p-2 hover:bg-white/5 rounded-md text-gray-300"
                onClick={() => setIsMenuOpen(false)}
              >
                İletişim
              </Link>
              <div className="p-2">
                <LanguageSwitcher currentLanguage="tr" onLanguageChange={() => {}} />
              </div>
            </div>
          </motion.div>
        )}
      </AnimatePresence>
    </header>
  )
}

